2001太空漫游 (豆瓣)
Description: 2001太空漫游电影简介和剧情介绍,2001太空漫游影评、图片、预告片、影讯、论坛、在线购票
Keywords: 2001太空漫游,2001: A Space Odyssey,2001太空漫游影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.192豆瓣电影Top250

# 2001太空漫游 2001: A Space Odyssey (1968)

导演: 斯坦利·库布里克
编剧: 亚瑟·克拉克 / 斯坦利·库布里克
主演: 凯尔·杜拉 / 加里·洛克伍德 / 威廉姆·西尔维斯特 / 丹尼尔·里希特 / 雷纳德·洛塞特 / 罗伯特·比提 / 肖恩·沙利文 / 艾德·毕肖普 / 格伦·贝克 / 艾伦·吉福德 / 安·吉利斯
类型: 科幻 / 惊悚 / 冒险
制片国家/地区: 英国 / 美国
语言: 英语 / 俄语
上映日期: 1968-04-02(华盛顿首映) / 1968-05-12(英国)
片长: 149分钟
又名: 2001：星际漫游 / 2001：太空奥德赛
IMDb: tt0062622
豆瓣评分
引用
8.9
299911人评价
5星
59.3%
4星
28.9%
3星
9.2%
2星
1.7%
1星
0.9%
好于 98% 科幻片
好于 99% 惊悚片
想看 看过
评价:
推荐

## 2001太空漫游的剧情简介 · · · · · ·

这部影片是库布里克花了四年时间制作的充满哲学命题的鸿篇巨制。一块大黑石树立在史前人类的面前，他们刚刚开始认识工具，进入到进化的里程碑。同样的黑石还在宇宙多处出现，它们矗立在月球上，漂浮在太空中，带着某种神秘的寓意。
现在的时间是2001年，为了寻找黑石的根源，人类开展一项木星登陆计划。飞船上有冬眠的三名宇航员，大卫船长（凯尔·杜拉 Keir Dullea饰）、富兰克飞行员（加里·洛克伍德 Gary Lockwood饰），还有一部叫“HAL9000”的高智能电脑。HAL在宇宙飞行过程中发生错乱，令到富兰克和三名冬眠人员相继丧命，剩下波曼和这台电脑作战。
从死亡线上回来的大卫一气之下关掉主脑系统，HAL彻底失效。现在，茫茫宇宙中只剩大卫一人，向木星进发。穿越瑰异壮观的星门，大卫仿佛去到一个奇特的时空，那里有人类无尽的生死轮回和宇宙的终极知识…… ©豆瓣

## 2001太空漫游的演职员 · · · · · · ( 全部 24 )

- 斯坦利·库布里克 导演
- 凯尔·杜拉 演员
- 加里·洛克伍德 演员
- 威廉姆·西尔维斯特 演员
- 丹尼尔·里希特 演员
- 雷纳德·洛塞特 演员

## 2001太空漫游的视频和图片 · · · · · · ( 预告片4 | 添加视频评论 | 图片995 · 添加 )

## 2001太空漫游的获奖情况 · · · · · · ( 全部 )

- 第41届奥斯卡金像奖
- 最佳导演(提名)
- 斯坦利·库布里克

- 第41届奥斯卡金像奖
- 最佳原创剧本(提名)
- 亚瑟·克拉克 / 斯坦利·库布里克

- 第41届奥斯卡金像奖
- 最佳视觉效果
- 斯坦利·库布里克

## 喜欢这部电影的人也喜欢 · · · · · ·

  大都会

  银翼杀手

  这个男人来自地球

  黑客帝国

  超时空接触

  回到未来

  E.T.外星人

  月球

  第九区

  终结者2：审判日

我要写短评

## 2001太空漫游的短评 · · · · · · ( 全部 93193 条 )

热门 / 最新 / 好友

### 3332 有用 地富反坏右 看过 2008-07-14 10:28:08

首先你得忍者看完第一遍,觉得不知道在说什么;看了第二遍,觉得好像有点意思;看第三遍,知道原来这个电影讲述的是多个主题啊,看第四遍,觉得好像看懂了点什么;看了第五遍,啊,真他妈太牛了!这可是1968年的东西!

### 3581 有用 思阳 看过 2008-02-29 14:05:22

这部片子有三个特征：1）看不懂 2）无数的符号 3）必须熟读尼采 4）六十年代能够做出这样的特效真的是惊天动地

### 7261 有用 彦夕 看过 2007-12-08 09:59:04

原作作者克拉克：“如果有人觉得完全弄懂了《太空漫游2001》在讲些什么，那一定是我和库布里克弄错了。”

### 725 有用 冬贝与9-13刺青 看过 2008-06-06 10:40:23

不好意思 我只能把经典电影给两星 因为不喜欢

### 2389 有用 Kuba 看过 2009-12-21 01:30:50

这部是唯一一出让我彻底游离出剧情，却始终带着浓厚兴趣看完的电影，我相信库布里克偏执的工作态度操死了一批又一批特效制作人员

> 更多短评 93193条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 2001太空漫游的影评 · · · · · · ( 全部 1235 条 )

热门 / 最新 / 好友
布瓜 2009-09-06 09:33:46

## 生命的奥德

这篇影评可能有剧透

我相信很多人跟我一样，第一次看2001:A SPACE ODYSSEY的时候都忍不住按了快进键，再不就是中间无法抗拒地昏睡过去。2010呢，由于知名度远不如2001（毕竟怎么说，2001是老库的作品嘛），很多人压根就没看过。 在连着读了克拉克的原著小说与重温两部翻拍电影之后，我终于解开了... (展开)
8670 207 425回应 收起
蟾宫 2007-05-06 03:41:08

## 轮回的讥讽与批判

被称为史上最深刻最富哲学涵义无人能懂的科幻电影。就是这部电影让我期待了整整4年。终于完完全全地看完了整部电影，发觉有很多东西都已经被抽干一般，需要不断地重复才能更在文本中发掘出来。仍决定写下对这部电影的浅见，只是为了见证自己的又一次探索，无论深浅。 题目。Ody... (展开)
1466 259 126回应 收起
堂怀瑟 2006-03-13 00:40:38

## 关于5分钟的黑暗和库布里克

"是电影感觉没有小说那么好，片子沉闷，而且晦涩。与通常的电影有很大的不同！！开头的一段黑暗，让人以为放映机器出故障了，飞船在太空行驶一段，用了很长的时间，没有进展任何情节。人物的对话相当少而且也很简单。到后面则没有了语言。一些奇怪的事发生（对没看过小说... (展开)
763 103 150回应 收起
意达的面包 2008-12-01 22:23:44

## it's space music

因为这部电影，NASA每天用来叫醒宇航员的音乐就是蓝色多瑙河。 因为这部电影，卢卡斯拍摄了星球大战系列。 因为这部电影，斯皮尔伯格做了导演。 阿波罗登月计划的宇航员在踏上月球真实的土地后，说“JUST LIKE THAT MOVIE” 库布里克采用的太空船和空间站设计，基本全部来自于... (展开)
386 38 18回应 收起
沧海客@爱翡翠 2007-04-01 12:11:03

## 人类命运的沉思——2001太空漫游

《2001 Space Odyssey》（中译为《2001太空漫游》）作为电影史上的经典之作，已经被人讨论分析过无数次了。在此，我无意对剧本作者阿瑟·克拉克与导演斯坦利·库布里克的本意进行详细的解释——在这样一部几乎完全开放给观众的影片面前，这种解释完全是徒劳的。 在影片... (展开)
394 55 32回应 收起
艾小柯 2007-03-01 15:45:04

## 最伟大导演拍摄的最伟大影片

我开始照着Sol Stein的书学习写小说的时候，Sol说了，写作最难的在于要"show the story"（展现故事），而不是"tell the story"（讲故事），也就是说，要让文字产生画面感，那是要下真功夫的。这让我想起来小时候语文课上学过的老舍先生那篇描写写夏天热的文章，其中令我印象最... (展开)
406 172 113回应 收起
颜 2010-10-22 17:32:39

## 转：《2001太空漫游》的幕后花絮

http://www.m1905.com/film/61183/feature/ 【库布里克的太空情结】 　　在完成《奇爱博士》(Dr. Strangelove)之后，斯坦利・库布里克对外太空生命产生了浓厚兴趣，于是决定拍摄一部意味深长的科幻片。在哥伦比亚公司职员罗杰・卡拉斯(Roger Caras)的建议下，库布里克找到... (展开)
201 15 9回应 收起
hilbertan 2008-04-05 12:50:38

## 扯淡的科幻和更加扯淡的评论们

这部电影最重大的特点是节奏拖沓——当然有人喜欢这种拖沓，这无可厚非。但是起码我很讨厌。艺术上的细节我不想多说，毕竟没有一个统一标准，这样的讨论除了最后搞成口水仗以外不会有任何积极效果。但是看完这个片子我的感觉是我被耍了，然而看完这么多影评以后，令我惊讶的是... (展开)
494 289 346回应 收起
夜帝不熬夜 2019-11-01 13:27:20 #关于《2001太空漫游》的精彩看点

## 看不懂《2001：太空漫游》？先看看原著小说对电影的八点补充与揭秘

这篇影评可能有剧透

作为历史上公认的科幻电影NO.1，《2001：太空漫游》一直是很多人心中必看的影片，但很多人都会被它晦涩难懂的剧情、缓慢的叙事节奏所吓倒，甚至有些人还没撑过影片开场没有一句对白的25分钟就昏昏欲睡，放弃了。 其实克拉克也意识到这个问题，他还说过：“如果有人觉得完全弄懂... (展开)
189 4 21回应 收起

> 更多影评 1235篇

添加新讨论

## 讨论区 · · · · · ·

难道没有人看完这部片子觉得一种难言的恐怖？ | 来自时间是食肉的 | 125 回应 | 2022-11-24 00:09:30
这部电影如果换成中国导演拍成这样的话还会不会有... | 来自一起都有可能 | 219 回应 | 2022-11-21 13:55:00
电影最后那一段什么意思啊？没太看懂。就是从主角... | 来自龙 | 16 回应 | 2022-11-20 23:38:44
普尔是被放弃了吗 | 来自瓜啊瓜啊瓜 | 2 回应 | 2022-11-20 21:42:47
最装X的电影 | 来自尘世修心 | 44 回应 | 2022-11-18 21:47:36

> 去这部影片的讨论区（全部366条）

## 关于《2001太空漫游》的问题 · · · · · · ( 全部35个 )

- 当Hal的内存条被拆差不多时候，它唱了一首Daisy，这首歌有何特殊含义？ 6人回答
- 1960s年代是怎么拍出逼真的失重戏的？ 5人回答

> 全部35个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 1905电影网 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 装13者必挂在嘴边的电影（近期开始陆续更新） (胡楚诗)
- 北京电影学院硕士要看的100部电影 (悲`馨)
- 【励志电影】 (影志)

## 谁在看这部电影 · · · · · ·

- mushroom
  4分钟前 想看
- Que七哒哒
  8分钟前 想看
- 走神儿
  13分钟前 看过

398317人看过 / 255824人想看

订阅2001太空漫游的评论:
feed: rss 2.0